pub fn paths_forced_by_projection(
keys: &[String],
exclude_keys: &[String],
) -> Vec<String>Expand description
The extra include paths keys and excludeKeys force (RestQuery.js:148-183).
A dotted projection needs its parent included, because the projection only ever names the
first component of a path on the class being queried. a.b.c therefore forces a.b.